---
title: Resource item
description: Resource items represent specific objects within a collection, such as products or orders. They provide contextual information on the resource type and link to the object’s detail page.
category: Lists and tables
keywords:
  - ResourceItem
  - resource item
  - collections
  - items
  - objects
  - list of products
  - list of orders
  - product lists
  - order lists
  - collections lists
  - collection lists
  - list of collections
  - product listings list
  - channel lists
  - resource list attributes
  - list attributes
  - exceptions list
  - list secondary actions
  - secondary actions in a list
  - list of resources
examples:
  - fileName: resource-item-default.tsx
    title: Default
    description: A basic resource item with its details filled in at the point of use.
  - fileName: resource-item-with-media.tsx
    title: With media
    description: The media element can hold an [avatar](https://polaris.shopify.com/components/avatar), [thumbnail](https://polaris.shopify.com/components/thumbnail), or other small-format graphic.
  - fileName: resource-item-with-shortcut-actions.tsx
    title: With shortcut actions
    description: Shortcut actions present popular actions from the resource’s details page for easy access. A shortcut action should be available on every item in the list.
  - fileName: resource-item-with-vertical-alignment.tsx
    title: With vertical alignment
    description: Use to adjust the vertical alignment of item content.
---

## Required components

The resource item component must be wrapped in the [resource list](https://polaris.shopify.com/components/resource-list) component.

---

## Accessibility

Resource items function as links to the full-page representations of the items. Each item should have a unique `name` prop. For each `ResourceItem`, the `accessibilityLabel` prop should be used to give the link a unique `aria-label` value. The `aria-label` value should convey the link’s purpose, using the `name` value. Merchants who use screen readers or other text to speech tools should be able to easily distinguish each link from the others.

When adding custom content to resource items, ensure that all text is available to all users and that all custom controls have a unique accessible name to help users understand what will happen when the control is activated.

### Keyboard

Links can be activated with the <kbd>enter</kbd>/<kbd>return</kbd> key by default.

If you add custom controls to resource items, then make sure that the controls:

- Can be used with the keyboard
- Receive keyboard focus in a logical order
- Display a visible focus indicator

---

## Best practices

Resource items should:

- Be tailored to the specific type of context being displayed.
- Perform an action when clicked. The action should navigate to the resource’s details page or provide more detail about the item.

Resource items can optionally:

- Provide [shortcut actions](https://polaris.shopify.com/components/resource-list#study-custom-item-shortcut-actions) for quick access to frequent actions from the resource’s details page.

---

## Content guidelines

Resource items should:

- Present the information that merchants need to find the items that they’re looking for.
- Support merchant tasks for the particular type of resource.
- Avoid colons.
- [Shortcut actions](https://polaris.shopify.com/components/resource-list#study-custom-item-shortcut-actions) don’t need to follow the full verb + noun formula for buttons.

---

## Related components

To display a simple list of related content, [use the list component](https://polaris.shopify.com/components/list).
